<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="et">
<context>
    <name>LXQtVolume</name>
    <message>
        <location filename="../lxqtvolume.cpp" line="64"/>
        <source>Increase sound volume</source>
        <translation>Suurenda helivaljust</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="70"/>
        <source>Decrease sound volume</source>
        <translation>Vähenda helivaljust</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="76"/>
        <source>Mute/unmute sound volume</source>
        <translation>Summuta või taasta heli</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="137"/>
        <source>Volume Control: The following shortcuts can not be registered: %1</source>
        <translation>Helivaljuse haldus: Järgnevat kiirklahvi ei õnnestu salvestada: %1</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="290"/>
        <source>Volume: %1%%2</source>
        <translation>Helivaljus: %1%%2</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="290"/>
        <source>(muted)</source>
        <translation>(summutatud)</translation>
    </message>
</context>
<context>
    <name>LXQtVolumeConfiguration</name>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="14"/>
        <source>Volume Control Settings</source>
        <translation>Helivaljuse halduse seadistused</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="20"/>
        <source>Device to control</source>
        <translation>Hallatav seade</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="28"/>
        <source>ALSA</source>
        <translation>ALSA</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="35"/>
        <source>PulseAudio</source>
        <translation>PulseAudio</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="42"/>
        <source>OSS</source>
        <translation>OSS</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="57"/>
        <source>Behavior</source>
        <translation>Tegevused</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="63"/>
        <source>Mute on middle click</source>
        <translation>Hiire keskmise klahviga vajutamine summutab heli</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="70"/>
        <source>Allow volume beyond 100% (0dB)</source>
        <translation>Luba helivaljus üle 100% (0dB)</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="77"/>
        <source>Always notify about volume changes</source>
        <translation>Alati teavita helivaljuse muutustest</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="84"/>
        <source>Notify about volume changes with keyboard</source>
        <translation>Teavita helivaljuse muutmisest klaviatuurilt</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="99"/>
        <source>Volume adjust step</source>
        <translation>Helivaljuse muutmise samm</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="118"/>
        <source>External Mixer</source>
        <translation>Võimalik väline helimikseri rakendus</translation>
    </message>
</context>
<context>
    <name>VolumePopup</name>
    <message>
        <location filename="../volumepopup.cpp" line="59"/>
        <source>Launch mixer</source>
        <translation>Käivita helimikser</translation>
    </message>
    <message>
        <location filename="../volumepopup.cpp" line="60"/>
        <source>Mi&amp;xer</source>
        <translation>Mi&amp;kser</translation>
    </message>
</context>
</TS>
